@@ -12,7 +12,7 @@ if ( empty($status->comment_status) ) {
 	exit;
 } elseif ( 'closed' ==  $status->comment_status ) {
 	do_action('comment_closed', $comment_post_ID);
-	die( __('Sorry, comments are closed for this item.') );
+	wp_die( __('Sorry, comments are closed for this item.') );
 } elseif ( 'draft' == $status->post_status ) {
 	do_action('comment_on_draft', $comment_post_ID);
 	exit;
@@ -37,27 +37,27 @@ if ( $user->ID ) {
 	}
 } else {
 	if ( get_option('comment_registration') )
-		die( __('Sorry, you must be logged in to post a comment.') );
+		wp_die( __('Sorry, you must be logged in to post a comment.') );
 }
 
 $comment_type = '';
 
-if ( get_settings('require_name_email') && !$user->ID ) {
+if ( get_option('require_name_email') && !$user->ID ) {
 	if ( 6 > strlen($comment_author_email) || '' == $comment_author )
-		die( __('Error: please fill the required fields (name, email).') );
+		wp_die( __('Error: please fill the required fields (name, email).') );
 	elseif ( !is_email($comment_author_email))
-		die( __('Error: please enter a valid email address.') );
+		wp_die( __('Error: please enter a valid email address.') );
 }
 
 if ( '' == $comment_content )
-	die( __('Error: please type a comment.') );
+	wp_die( __('Error: please type a comment.') );
 
 $commentdata = compact('comment_post_ID', 'comment_author', 'comment_author_email', 'comment_author_url', 'comment_content', 'comment_type', 'user_ID');
 
 $comment_id = wp_new_comment( $commentdata );
 
+$comment = get_comment($comment_id);
 if ( !$user->ID ) :
-	$comment = get_comment($comment_id);
 	setcookie('comment_author_' . COOKIEHASH, $comment->comment_author, time() + 30000000, COOKIEPATH, COOKIE_DOMAIN);
 	setcookie('comment_author_email_' . COOKIEHASH, $comment->comment_author_email, time() + 30000000, COOKIEPATH, COOKIE_DOMAIN);
 	setcookie('comment_author_url_' . COOKIEHASH, clean_url($comment->comment_author_url), time() + 30000000, COOKIEPATH, COOKIE_DOMAIN);
